@@ -2,6 +2,7 @@ import docker
 # from bacchus.homeassistant import HomeAssistant
 from bacchus.jackett import Jackett
 from bacchus.transmission import Transmission
+from bacchus.lazylibrarian import LazyLibrarian
 from bacchus.lidarr import Lidarr
 from bacchus.radarr import Radarr
 from bacchus.medusa import Medusa
@@ -10,11 +11,12 @@ from bacchus.nginx import Nginx
 from bacchus.compose import DockerCompose
 from bacchus.openvpn import OpenVPN
 from bacchus.jellyfin import Jellyfin
+from bacchus.lazylibrarian import LazyLibrarian
 from bacchus.certificates import CertManager
 
 __all__ = [
     CertManager, Nginx, OpenVPN, NextCloud, Transmission, Jackett, Lidarr,
-    Radarr, Medusa, Jellyfin
+    LazyLibrarian, Radarr, Medusa, Jellyfin
 ]
 
 
